@@ -196,6 +196,7 @@ set_word (SpellControlData *cd, gchar *word)
 		gtk_clist_select_row (GTK_CLIST (cd->clist_suggestions), 0, 0);
 		gtk_clist_thaw (GTK_CLIST (cd->clist_suggestions));
 		gtk_widget_grab_focus (cd->clist_suggestions);
+		gtk_widget_set_sensitive (GTK_WIDGET (cd->button_replace), seq->_length != 0);
 
 		CORBA_free (seq);
 	}
@@ -210,7 +211,7 @@ set_language (SpellControlData *cd, gchar *language)
 	cd->language = g_strdup (language);
 
 	CORBA_exception_init (&ev);
-	GNOME_Spell_Dictionary_setTag (cd->dict, "language-tag", cd->language, &ev);
+	GNOME_Spell_Dictionary_setLanguage (cd->dict, cd->language, &ev);
 	CORBA_exception_free (&ev);
 }
 
@@ -253,7 +254,6 @@ spell_control_construct (BonoboControl *control, GtkWidget *table, GladeXML *xml
 {
 	BonoboArg *def;
 	SpellControlData *cd;
-	CORBA_Environment ev;
 
 	cd = g_new0 (SpellControlData, 1);
 	cd->control = control;
@@ -311,14 +311,6 @@ spell_control_construct (BonoboControl *control, GtkWidget *table, GladeXML *xml
 	cd->dict_client = bonobo_object_activate ("OAFIID:GNOME_Spell_Dictionary:" API_VERSION, 0);
 	cd->dict = BONOBO_OBJREF (cd->dict_client);
 
-	CORBA_exception_init (&ev);
-	GNOME_Spell_Dictionary__set_active (cd->dict, CORBA_TRUE, &ev);
-	CORBA_exception_free (&ev);
-
-	CORBA_exception_init (&ev);
-	GNOME_Spell_Dictionary_setTag (cd->dict, "encoding", "utf-8", &ev);
-	CORBA_exception_free (&ev);
-
 	set_language (cd, "en");
 }
 
