@@ -36,12 +36,16 @@ BEGIN_GNOME_DECLS
 #define IS_GNOME_SPELL_DICTIONARY_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GNOME_SPELL_DICTIONARY_TYPE))
 
 typedef struct {
-	BonoboObject parent;
-
-	gboolean active;
-	gboolean changed;
 	PspellConfig  *config;
 	PspellManager *manager;
+	gboolean       changed;
+} SpellEngine;
+
+typedef struct {
+	BonoboObject parent;
+
+	gboolean changed;
+	GSList *engines;
 } GNOMESpellDictionary;
 
 typedef struct {
