@@ -27,23 +27,19 @@
 #include <bonobo.h>
 #include "Spell.h"
 #include "dictionary.h"
-#include "checker.h"
 #include "control.h"
 
 CORBA_Environment ev;
 CORBA_ORB orb;
 
 static BonoboGenericFactory *dictionary_factory;
-static BonoboGenericFactory    *checker_factory;
 static BonoboGenericFactory    *control_factory;
 
 static int active_dictionary_servers = 0;
-static int active_checker_servers = 0;
 static int active_control_servers = 0;
 
 typedef enum {
 	TYPE_DICTIONARY,
-	TYPE_CHECKER,
 	TYPE_CONTROL,
 } SpellObjectType;
 
@@ -67,9 +63,8 @@ try_quit ()
 	/* printf ("Try quit:\n\tchecker: %d\n\tdictionary: %d\n\tcontrol: %d\n",
 	   active_checker_servers, active_dictionary_servers, active_control_servers); */
 
-	if (active_checker_servers || active_dictionary_servers || active_control_servers)
+	if (active_dictionary_servers || active_control_servers)
 		return;
-	bonobo_object_unref (BONOBO_OBJECT (checker_factory));
 	bonobo_object_unref (BONOBO_OBJECT (dictionary_factory));
 	bonobo_object_unref (BONOBO_OBJECT (control_factory));
 
@@ -77,7 +72,7 @@ try_quit ()
 }
 
 static void
-object_destroyed (GtkObject *checker_object, gpointer data)
+object_destroyed (GtkObject *object, gpointer data)
 {
 	(*(gint *) data) --;
 
@@ -95,10 +90,6 @@ factory_object_new (BonoboGenericFactory *this_factory, gpointer data)
 		new_object = gnome_spell_dictionary_new ();
 		counter    = &active_dictionary_servers;
 		break;
-	case TYPE_CHECKER:
-		new_object = gnome_spell_checker_new ();
-		counter    = &active_checker_servers;
-		break;
 	case TYPE_CONTROL:
 		new_object = gnome_spell_control_new ();
 		counter    = &active_control_servers;
@@ -120,9 +111,6 @@ factory_object_new (BonoboGenericFactory *this_factory, gpointer data)
 static void
 factory_init (void)
 {
-	checker_factory = bonobo_generic_factory_new
-		("OAFIID:GNOME_Spell_CheckerFactory:" API_VERSION,
-		 factory_object_new, GINT_TO_POINTER (TYPE_CHECKER));
 	dictionary_factory = bonobo_generic_factory_new
 		("OAFIID:GNOME_Spell_DictionaryFactory:" API_VERSION,
 		 factory_object_new, GINT_TO_POINTER (TYPE_DICTIONARY));
@@ -130,8 +118,6 @@ factory_init (void)
 		("OAFIID:GNOME_Spell_ControlFactory:" API_VERSION,
 		 factory_object_new, GINT_TO_POINTER (TYPE_CONTROL));
 
-	if (!checker_factory)
-		g_error ("It was not possible to register a new checker factory");
 	if (!dictionary_factory)
 		g_error ("It was not possible to register a new dictionary factory");
 	if (!control_factory)
@@ -142,8 +128,8 @@ int
 main (int argc, char *argv [])
 {
 	/* Initialize the i18n support */
-	bindtextdomain(PACKAGE, GNOMELOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain ("gnome-spell-" VERSION, GNOMELOCALEDIR);
+	textdomain ("gnome-spell-" VERSION);
 
 	CORBA_exception_init (&ev);
 
