@@ -57,36 +57,32 @@ int
 main (int argc, char *argv [])
 {
 	BonoboObjectClient *checker_client, *dictionary_client;
-	GNOME_Spell_Checker checker;
 	GNOME_Spell_Dictionary en;
 	GNOME_Spell_StringSeq *seq;
 	CORBA_Environment   ev;
-	char *checker_id, *dictionary_id;
+	char *dictionary_id;
 	gint i;
 
 	init_bonobo (argc, argv);
 
-	   checker_id = "OAFIID:GNOME_Spell_Checker:"    API_VERSION;
 	dictionary_id = "OAFIID:GNOME_Spell_Dictionary:" API_VERSION;
-
-	   checker_client = bonobo_object_activate (checker_id, 0);
 	dictionary_client = bonobo_object_activate (dictionary_id, 0);
 
-	if (check_obj (checker_client, checker_id)
-	    || check_obj (dictionary_client, dictionary_id))
+	if (check_obj (dictionary_client, dictionary_id))
 		return 1;
 	CORBA_exception_init (&ev);
 
 	/*
 	 * Get the CORBA Object reference from the BonoboObjectClient
 	 */
-	checker = bonobo_object_corba_objref (BONOBO_OBJECT (checker_client));
 	en      = bonobo_object_corba_objref (BONOBO_OBJECT (dictionary_client));
 
 	/*
 	 * test dictionary
 	 */
-	GNOME_Spell_Dictionary_setTag (en, "language-tag", "en", &ev);
+
+	GNOME_Spell_Dictionary_getLanguages (en, &ev);
+	GNOME_Spell_Dictionary_setLanguage (en, "en", &ev);
 
 	printf ("check: %s --> %d\n",
 		"helo",
@@ -95,23 +91,6 @@ main (int argc, char *argv [])
 		"hello",
 		GNOME_Spell_Dictionary_checkWord (en, "hello", &ev));
 
-	printf ("get active: %d\n", GNOME_Spell_Dictionary__get_active (en, &ev));
-	printf ("set active: %d\n", 0);
-	GNOME_Spell_Dictionary__set_active (en, CORBA_FALSE, &ev);
-	printf ("get active: %d\n", GNOME_Spell_Dictionary__get_active (en, &ev));
-
-	printf ("check: %s --> %d\n",
-		"helo",
-		GNOME_Spell_Dictionary_checkWord (en, "helo", &ev));
-	printf ("check: %s --> %d\n",
-		"hello",
-		GNOME_Spell_Dictionary_checkWord (en, "hello", &ev));
-
-	printf ("set active: %d\n", 1);
-	GNOME_Spell_Dictionary__set_active (en, CORBA_TRUE, &ev);
-	printf ("check: %s --> %d\n",
-		"helo",
-		GNOME_Spell_Dictionary_checkWord (en, "helo", &ev));
 	seq = GNOME_Spell_Dictionary_getSuggestions (en, "helo", &ev);
 	printf ("suggestions for helo\n");
 	for (i=0; i<seq->_length; i++)
@@ -124,7 +103,6 @@ main (int argc, char *argv [])
 		GNOME_Spell_Dictionary_checkWord (en, "helo", &ev));
 	CORBA_exception_free (&ev);
 
-	bonobo_object_unref (BONOBO_OBJECT (checker_client));
 	bonobo_object_unref (BONOBO_OBJECT (dictionary_client));
 	
 	return 0;
